from azure.identity import DefaultAzureCredential#,AzureDeveloperCliCredential
from azure.mgmt.resource import ResourceManagementClient

def capacity_status(subscription_id,resource_group_name,capacity_name):

    # Authenticate using default credentials
    #credential = AzureDeveloperCliCredential() # With Azure Developer Credential we are able to authenticate with azd auth login  and test with Visual Studio
    credential = DefaultAzureCredential()

    resource_client = ResourceManagementClient(credential, subscription_id)

    # Get the capacity resource
    capacity_resource = resource_client.resources.get_by_id(
        f"/subscriptions/{subscription_id}/resourceGroups/{resource_group_name}/providers/Microsoft.Fabric/capacities/{capacity_name}",
        "2022-07-01-preview"
    )

    # Check if the capacity is active
    print(capacity_resource.properties["provisioningState"])
    return capacity_resource.properties["provisioningState"]







import os
import requests

def operate(operation,base_url,token,sku=None):

    if operation == "resume":

        url = f"{base_url}/resume?api-version=2022-07-01-preview"
        print(f"INFO: Calling {url}")
        response = requests.post(url, headers={'Content-Type': 'application/json', "Authorization": f"Bearer {token}"})
        if not response.ok and response.json()["error"]["message"] == 'Service is not ready to be updated':
            print(f"WARN: Service is not ready to be updated, probably it is already in desired state: {operation}")
        else:
            response.raise_for_status()

    elif operation == "suspend":

        url = f"{base_url}/suspend?api-version=2022-07-01-preview"
        print(f"INFO: Calling {url}")
        response = requests.post(url, headers={'Content-Type': 'application/json', "Authorization": f"Bearer {token}"})
        if not response.ok and response.json()["error"]["message"] == 'Service is not ready to be updated':
            print(f"WARN: Service is not ready to be updated, probably it is already in desired state: {operation}")
        else:
            response.raise_for_status()

    else:
        url = f"{base_url}?api-version=2022-07-01-preview"
        print(f"INFO: Scaling {url} to {sku}")
        payload = {"sku":{"name": sku,"tier":"Fabric"}}
        response = requests.patch(url, headers={'Content-Type': 'application/json', "Authorization": f"Bearer {token}"}, json=payload)
        response.raise_for_status()





from setuptools import setup, find_packages

setup(
    name="fcapacity_mngmt",
    version="2.5",
    author="Jorge Marmol",
    author_email="marmoljorge98@gmail.com",
    packages=find_packages(),
    install_requires=["azure-identity","azure-mgmt-resource"],  # Agrega las dependencias si las tienes
)


# python setup.py sdist
